.. Lollipop documentation master file

*********************************************
lollipop: object serialization and validation
*********************************************

Release version |version|. (:ref:`Changelog <changelog>`)

Guide
=====

.. toctree::
    :maxdepth: 2

    install
    quickstart
    objects
    modifiers
    validation
    custom_types

API Reference
=============

.. toctree::
    :maxdepth: 3

    api_reference

Other information
=================

.. toctree::
    :maxdepth: 1

    why
    changelog
    license
    kudos
